bayespy.inference.vmp.transformations.RotateGaussian.__init__
=============================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. automethod:: RotateGaussian.__init__